markuptools.MarkupCommand
=========================

.. abjad-lineage:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand

.. autoclass:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.args
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.command
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.lilypond_format
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.storage_format
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__eq__
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ne__
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__repr__
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.args
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.command
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.storage_format
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__str__
   :noindex:
